Skip to contents

AGA16.tw.C01 returns the ground-motion prediction with it sigma of Abrahamson et al.(2016) GMPE adjusted to Taiwan.

Usage

AGA16.tw.C01(Mag, Rrup, Prd, ftype = 0, Vs30, Ztor, depth, Rhypo)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

fytpe=0 for interface (use rupture distance), ftype=1 for intraslab (use hypocentral distance)

Vs30

Vs30(m/s).

Ztor

Depth to the top of the finite rupture model (km).

depth

hypocentral depth(km).

Rhypo

hypocentral distance(km)

Value

A list will be return, including mag, ftype, Rrup, Vs30, lnY, sigma, specT, period, iflag, forearc, depth, Rhypo, deltac1.

Details

Norman Abrahamson, Nicholas Gregor, and Kofi Addo(2016) BC Hydro Ground Motion Prediction Equations for Subduction Earthquakes, Earthquake Spectra, Vol. 32, No. 1, pp. 23-44. doi:10.1193/051712EQS188MR

Examples

AGA16.tw.C01(6, 20, 0, 0, 760, 3, 10, 20)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 3.652036
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7381734
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $Ztor
#> [1] 3
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
AGA16.tw.C01(7, 10, 0, 0, 760, 0, 10, 20)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.121412
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7381734
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>