Skip to contents

ASB14.tw.E02 returns the ground-motion prediction with it sigma of Akkar et al.(2014) GMPE adjusted to Taiwan.

Usage

ASB14.tw.E02(Mag, Rjb, Prd = 0, ftype = 0, Vs30 = 760)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rjb

Joyner and Boore distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

style of faulting.

Vs30

Vs30(m/s).

Value

A list will be return, including mag, Rjb, specT, period, lnY, sigma, iflag, ftype, Vs30, phi, tau.

Details

Akkar, S., M. a. Sandikkaya, and J. J. Bommer(2014), Empirical ground-motion models for point- and extended-source crustal earthquake scenarios in europe and the middle east, Bulletin of Earthquake Engineering, Volume 12, Issue 1, pp 359-387. doi:10.1007/s10518-013-9461-4

Examples

ASB14.tw.E02(6, 20, 0, 0, 760)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.269635
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7121054
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.6201
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3501
#> attr(,"Csingle")
#> [1] TRUE
#> 
ASB14.tw.E02(7, 10, 0, 0, 760)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.773791
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7121054
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.6201
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3501
#> attr(,"Csingle")
#> [1] TRUE
#>