Skip to contents

ASK14.tw.C01 returns the ground-motion prediction with it sigma of Abrahamson et al.(2014) GMPE adjusted to Taiwan.

Usage

ASK14.tw.C01(
  Mag,
  Rrup,
  Rjb,
  Prd,
  Dip,
  ftype = 0,
  rupwidth,
  Vs30 = 760,
  hwflag = 0,
  Ztor,
  Vs30_class = 1,
  Z1.0,
  Rx,
  Ry0,
  regionflag = 0,
  msasflag = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Rjb

Joyner and Boore distance(km), Numeric.

Prd

Period of spectral acceleration.

Dip

Dip angle of the fault plane.

ftype

style of faulting.

rupwidth

Down-dip rupture width (km).

Vs30

Vs30(m/s).

hwflag

hanging-wall flag, 1 for hanging-wall.

Ztor

Depth to the top of the finite rupture model (km).

Vs30_class

1 measured, 0 estimated.

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

Rx

Horizontal distance(km) from top edge of rupture. Measured perpendicular to the fault strike.

Ry0

Horizontal distance(km) off the end of the rupture measured parallel to strike.

regionflag

Regional attenuation flag, 0 = Global, 1 = Taiwan, 2 = China, 3 = Japan.

msasflag

Mainshock and Aftershocks flag, 0 = Mainshocks, 1 = Aftershocks.

Value

A list will be return, including mag, dip, ftype, rupwidth, Rrup, Rjb, Vs30, hwflag, lnY, sigma, specT, period, Ztor, iflag, vs30_class, z10, Rx, Ry0, regionflag, msasflag, phi, tau.

Details

Abrahamson, N. A., W. J. Silva, and R. Kamai (2014), Summary of the ASK14 ground motion relation for active crustal regions, Earthquake Spectra, 30(3), 1025-1055. doi:10.1193/070913EQS198M

Examples

ASK14.tw.C01(6, 20, 20, 0, 90, 0, 10, 760, 0, 0, 1, 0.5, 20, 10, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $lnY
#> [1] 4.294102
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6505582
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $vs30_class
#> [1] 1
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ry0
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $msasflag
#> [1] 0
#> 
#> $phi
#> [1] 0.501
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.415
#> attr(,"Csingle")
#> [1] TRUE
#> 
ASK14.tw.C01(7, 20, 20, 0, 90, 0, 10, 760, 0, 0, 1, 0.5, 20, 10, 0, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $lnY
#> [1] 5.103639
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6169287
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $vs30_class
#> [1] 1
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ry0
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $msasflag
#> [1] 0
#> 
#> $phi
#> [1] 0.501
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.36
#> attr(,"Csingle")
#> [1] TRUE
#>