Skip to contents

Arroyo2010 returns the ground-motion prediction with it sigma of Arroyo et al. (2010) GMPE.

Usage

Arroyo2010(Mag, Rrup, Prd)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

Value

A list will be return, including mag, Rrup, lnY, specT, iflag, period, phi1, tau1, sigma.

Details

Arroyo, D. Garcia, M. Ordaz, M. A. Mora, and S. K. Singh. Strong ground-motion relations for Mexican interplate earthquakes. Journal of Seismology, 14(4):769-785, Oct 2010. https://link.springer.com/article/10.1007/s10950-010-9200-0

Examples

Arroyo2010(6, 20, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.576124
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.5882
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.4654
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.75
#> attr(,"Csingle")
#> [1] TRUE
#> 
Arroyo2010(7, 10, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 6.040587
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.5882
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.4654
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.75
#> attr(,"Csingle")
#> [1] TRUE
#>