Skip to contents

BCHydroSubV3 returns the ground-motion prediction with it sigma of Abrahamson et al.(2016) GMPE.

Usage

BCHydroSubV3(Mag, Rrup, Prd, ftype = 0, Vs30, forearc = 1, depth, Rhypo)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

fytpe=0 for interface (use rupture distance), ftype=1 for intraslab (use hypocentral distance)

Vs30

Vs30(m/s).

forearc

0 = Forearc site, 1 = Backarc site

depth

hypocentral depth(km).

Rhypo

hypocentral distance(km)

Value

A list will be return, including mag, ftype, Rrup, Vs30, lnY, sigma, specT, period, iflag, forearc, depth, Rhypo, deltac1.

Details

Norman Abrahamson, Nicholas Gregor, and Kofi Addo(2016) BC Hydro Ground Motion Prediction Equations for Subduction Earthquakes, Earthquake Spectra, Vol. 32, No. 1, pp. 23-44. doi:10.1193/051712EQS188MR

Examples

BCHydroSubV3(6, 20, 0, 0, 760, 1, 10, 20)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.175428
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7381734
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $forearc
#> [1] 1
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $deltac1
#> [1] 0.2
#> attr(,"Csingle")
#> [1] TRUE
#> 
BCHydroSubV3(7, 10, 0, 0, 760, 1, 10, 20)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.766958
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7381734
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $forearc
#> [1] 1
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $deltac1
#> [1] 0.2
#> attr(,"Csingle")
#> [1] TRUE
#>