Skip to contents

CB14.tw.C01 returns the ground-motion prediction with it sigma of Campbell and Bozorgnia(2014) GMPE adjusted to Taiwan..

Usage

CB14.tw.C01(
  Mag,
  Rrup,
  Rjb,
  ftype = 0,
  Prd,
  Vs30 = 760,
  Ztor,
  Z2.5,
  Dip,
  depth,
  hwflag = 0,
  Rx,
  rupwidth,
  regionflag = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Rjb

Joyner-Boore distance(km), Numeric.

ftype

style of faulting.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

Ztor

Depth to the top of the finite rupture model (km).

Z2.5

the depth to the shear-wave velocity horizon of 2.5(km/s).

Dip

Dip angle of the fault plane.

depth

hypocentral depth(km).

hwflag

hanging-wall flag, 1 for hanging-wall.

Rx

Horizontal distance(km) from top edge of rupture. Measured perpendicular to the fault strike.

rupwidth

Down-dip rupture width (km).

regionflag

Regional attenuation flag, 0 = California, 1 = Japan 2 = China, 3 = Italy.

Value

A list will be return, including mag, Rrup, Rjb, ftype, specT, period, lnY, sigma, iflag, Vs30, Ztor, Z25, dip, depth, hwflag, Rx, rupwidth, regionflag, phi, tau.

Details

Campbell, K. W., and Y. Bozorgnia (2014), NGA-west2 ground motion model for the average horizontal components of PGA, PGV, and 5 Earthquake Spectra, 30(3), 1087-1115. doi:10.1193/062913EQS175M

Examples

CB14.tw.C01(6, 20, 20, 0, 0, 760, 0, 1.5, 90, 10, 0, 20, 10, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 3.985774
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.5876462
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z2.5
#> [1] 1.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $phi
#> [1] 0.4905821
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3235077
#> attr(,"Csingle")
#> [1] TRUE
#> 
CB14.tw.C01(7, 20, 20, 0, 0, 760, 0, 1.5, 90, 10, 0, 20, 10, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.379045
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.5867481
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z2.5
#> [1] 1.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $phi
#> [1] 0.4899474
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3228389
#> attr(,"Csingle")
#> [1] TRUE
#>