Skip to contents

CY14.tw.B01 returns the ground-motion prediction with it sigma of Chiou and Youngs(2014) GMPE adjusted to Taiwan.

Usage

CY14.tw.B01(
  Mag,
  Rrup,
  Rjb,
  Prd,
  Vs30,
  Dip,
  Ztor,
  ftype = 0,
  Z1.0,
  Vs30_class = 1,
  hwflag = 0,
  Rx,
  regionflag = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Rjb

Joyner and Boore distance(km), Numeric.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

Dip

Dip angle of the fault plane.

Ztor

Depth to the top of the finite rupture model (km).

ftype

style of faulting.

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

Vs30_class

1 measured, 0 estimated.

hwflag

hanging-wall flag, 1 for hanging-wall.

Rx

Horizontal distance(km) from top edge of rupture. Measured perpendicular to the fault strike.

regionflag

0 Global, 1 Japan and Italy, 2 Wenchuan (note only for M7.9)

Value

A list will be return, including mag, Rrup, Rjb, specT, period, lnY, sigma, iflag, Vs30, dip, Ztor, ftype, Z10, vs3-_class, hwflag, Rx, regionflag, phi, tau.

Details

Chiou, B. S.-J., and R. R. Youngs (2014), Update of the chiou and youngs NGA model for the average horizontal component of peak ground motion and response spectra, Earthquake Spectra, 30(3), 1117-1153. doi:10.1193/072813EQS219M

Examples

CY14.tw.B01(6, 20, 20, 0, 760, 90, 0, 0, 0.5, 1, 0, 20, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.309154
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6201293
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $phi
#> [1] 0.5395289
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3057268
#> attr(,"Csingle")
#> [1] TRUE
#> 
CY14.tw.B01(7, 20, 20, 0, 760, 90, 0, 0, 0.5, 1, 0, 20, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.016343
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.5535139
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
#> $phi
#> [1] 0.4892633
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.2588416
#> attr(,"Csingle")
#> [1] TRUE
#>