Skip to contents

Chao2018 returns the ground-motion prediction with it sigma of Chao et al.(2018) GMPE.

Usage

Chao2018(
  Mag,
  Rrup,
  Prd = 0,
  ftype = 0,
  Vs30 = 760,
  Vs30_class = 0,
  Ztor = 0,
  Z1.0 = 0.0058959,
  sourcetype = 0,
  msasflag = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

style of faulting, -1 for Normal, 0 for Strike-Slip, 1 for Reverse for sourcetype = 0. 0 for interface, 1 for intraslab for soucetype = 1.

Vs30

Vs30(m/s).

Vs30_class

Vs30 data class, 0 for estimated, 1 for measured.

Ztor

Depth to the top of the finite rupture model (km).

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

sourcetype

source type, 0 for crustal, 1 for Subduction.

msasflag

Mainshock and Aftershocks flag, 0 = Mainshocks, 1 = Aftershocks.

Value

A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.

Details

Chao et al.(2018)

Examples

Chao2018(6, 20, 0, 0, 760, 0, 0, 0, 0)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] -Inf
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.659196
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z10
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30_class
#> [1] 0
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.5717019
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.328171
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $msasflag
#> [1] 0
#> 
Chao2018(7, 10, 0, 0, 760, 0, 0, 0, 0)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] -Inf
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6362015
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z10
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30_class
#> [1] 0
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.5526204
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.315219
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $msasflag
#> [1] 0
#>