Cru.Com.003 returns the ground-motion prediction with it sigma of Crustal Common form 003 GMPE.
Arguments
- Mag
Earthquake momnet magnitude, Numeric.
- Rrup
Rupture distance(km), Numeric.
- Rjb
Joyner and Boore distance(km), Numeric.
- Ztor
Depth to the top of the finite rupture model (km).
- ftype
style of faulting.
- Dip
Dip angle of the fault plane.
- rupwidth
Down-dip rupture width (km).
- Rx
Horizontal distance(km) from top edge of rupture. Measured perpendicular to the fault strike.
- hwflag
hanging-wall flag, 1 for hanging-wall.
- Prd
Period of spectral acceleration.
Value
A list will be return, including mag, Rrup, Rjb, Ztor, ftype, dip, rupwidth, Rx, hwflag, pecT, lnY, sigma, iflag.
Examples
Cru.Com.003(6, 20, 20, 5, 0, 90, 20, 20, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Ztor
#> [1] 5
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $rupwidth
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $hwflag
#> [1] 0
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.033009
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.65
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
Cru.Com.003(7, 20, 20, 2, 0, 90, 20, 20, 0, 0 )
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Ztor
#> [1] 2
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $rupwidth
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $hwflag
#> [1] 0
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.591617
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.65
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>