Skip to contents

Garcia05 returns the ground-motion prediction with it sigma of Garcia et al.(2005) GMPE.

Usage

Garcia05(Mag, Rrup, Prd, depth)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

depth

hypocentral depth(km).

Value

A list will be return, including mag, Rrup, specT, period, lnY, sigma, iflag, depth.

Details

Garcia, D., Singh, S. K., Herraiz, M., Ordaz, M., &Pacheco, J. F. (2005). Inslab Earthquakes of Central Mexico: Peak Ground-Motion Parameters and Response Spectra. Bulletin of the Seismological Society of America, 95(6), 2272-2282.

Examples

Garcia05(6, 20, 0, 35)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.066532
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6447238
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $depth
#> [1] 35
#> attr(,"Csingle")
#> [1] TRUE
#> 
Garcia05(7, 10, 0, 60)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 6.554275
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6447238
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $depth
#> [1] 60
#> attr(,"Csingle")
#> [1] TRUE
#>