Skip to contents

Gregor06 returns the ground-motion prediction with it sigma of Gregor et al.(2006) GMPE.

Usage

Gregor06(Mag, Rrup, Prd, Vs30)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

Value

A list will be return, including mag, Rrup, lnY, sigma, specT, attenName, Vs30, period, iflag.

Details

Gregor, N., W. Silva, I. Wong, and R. Youngs (2006), Updated response spectral attenuation relationship for cascadia subduction zone megathrust earthquake, Seismological Research Letters, 77(2), 325-326.

Examples

Gregor06(6, 20, 0, 760)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 3.609112
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7028
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
Gregor06(7, 10, 0, 760)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.570811
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7028
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#>