Skip to contents

I14.tw.B01 returns the ground-motion prediction with it sigma of Idriss, I. M. (2014) GMPE adjusted to Taiwan.

Usage

I14.tw.B01(Mag, Rrup, Prd = 0, ftype = 0, Vs30 = 760)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

style of faulting.

Vs30

Vs30(m/s).

Value

A list will be return, including mag, Rrup, ftype, Vs30, specT, period, lnY, sigma, iflag.

Details

Idriss, I. M. (2014). An NGA-West2 Empirical Model for Estimating the Horizontal Spectral Values Generated by Shallow Crustal Earthquakes. Earthquake Spectra, 30(3), 1155-1177. doi:10.1193/070613EQS195M Notes: Applicable Range (see Abstract): 5 <= M <= 8.5 Vs>=450 m/sec for Vs>1200 use Vs=1200 Rrup <= 150 km Mechanisms: Strike-slip and Norml (0) Reverse and Oblique (1)

Examples

I14.tw.B01(6, 20, 0, 0, 760)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.31842
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7151493
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
I14.tw.B01(7, 10, 0, 0, 760)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.768979
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6551493
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#>