Skip to contents

KAAH15 returns the ground-motion prediction with it sigma of Kale et al.(2015) GMPE.

Usage

KAAH15(Mag, Rjb, Prd = 0, ftype = 0, Vs30 = 760, regionflag = 0)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rjb

Joyner and Boore distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

style of faulting.

Vs30

Vs30(m/s).

regionflag

0 for Turkey, 1 for Iran.

Value

A list will be return, including mag, Rjb, specT, period, lnY, sigma, iflag, ftype, Vs30, pgaref, region.

Details

Kale, O., S. Akkar, A. Ansari, and H. Hamzehloo (2015), A ground-Motion predictive model for Iran and Turkey for horizontal PGA, PGV, and 5 Possible Regional Effects, Bulletin of the Seismological Society of America, 105(2A), 963-980. doi:10.1785/0120140134

Examples

KAAH15(6, 20, 0, 0, 760, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.022351
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7267771
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $pgaref
#> [1] 0.05714941
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#> 
KAAH15(7, 10, 0, 0, 760, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.474814
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.5737714
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $pgaref
#> [1] 0.2442352
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $regionflag
#> [1] 0
#>