Skip to contents

Kanno06 returns the ground-motion prediction with it sigma of Kanno et al.(2006) GMPE.

Usage

Kanno06(Mag, Rrup, Prd, Vs30, depth)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

depth

hypocentral depth(km).

Value

A list will be return, including mag, Rrup, specT, period, lnY, sigma, iflag, Vs30, depth.

Details

Kanno, T., A. Narita, N. Morikawa, H. Fujiwara, and Y. Fukushima (2006), A new attenuation relation for strong ground motion in japan based on recorded data, Bulletin of the Seismological Society of America, 96(3), 879-897. doi:10.1785/0120050138

Examples

Kanno06(6, 20, 0, 760, 10)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.414084
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.8519565
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
Kanno06(7, 10, 0, 760, 10)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.703321
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.8519565
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>