Skip to contents

LL08Soil returns the ground-motion prediction (soil site) with it sigma of Lin and Lee(2008) GMPE.

Usage

LL08Soil(Mag, Rrup, depth, ftype, Prd)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

depth

hypocentral depth(km).

ftype

fytpe=0 for interface, ftype=1 for intraslab

Prd

Period of spectral acceleration.

Value

A list will be return, including mag, Rrup, specT, period, lnY, sigma, iflag, depth, ftype.

Details

Lin, P., and C. Lee (2008), Ground-motion attenuation relationships for subduction-zone earthquakes in northeastern taiwan, Bulletin of the Seismological Society of America, 98(1), 220-240. doi:10.1785/0120060002

Examples

LL08Soil(6, 20, 10, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.86927
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6277
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
LL08Soil(7, 10, 10, 0, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.616729
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6277
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>