Skip to contents

Lin11Soil returns the ground-motion prediction (soil site) with it sigma of Lin et al.(2011) GMPE.

Usage

Lin11Soil(Mag, Rrup, Prd, hwflag = 0)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

hwflag

hanging-wall flag, 1 for hanging-wall.

Value

A list will be return, including mag, Rrup, specT, period, lnY, sigma, iflag.

Details

Lin, P.-S., C.-T. Lee, C.-T. Cheng, and C.-H. Sung (2011), Response spectral attenuation relations for shallow crustal earthquakes in taiwan, Engineering Geology, 121(3-4), 150-164. doi:10.1016/j.enggeo.2011.04.019

Examples

Lin11Soil(6, 20, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.502309
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.63
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
Lin11Soil(7, 10, 0, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.703135
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.63
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#>