MBR17 returns the ground-motion prediction with it sigma of Montalva et al.(2017) GMPE.
Arguments
- Mag
Earthquake momnet magnitude, Numeric.
- Rrup
Rupture distance(km), Numeric.
- Prd
Period of spectral acceleration.
- ftype
fytpe=0 for interface (use rupture distance), ftype=1 for intraslab (use hypocentral distance).
- Vs30
Vs30(m/s).
- forearc
0 = Forearc site, 1 = Backarc site.
- depth
hypocentral depth(km).
- Rhypo
hypocentral distance(km).
Value
A list will be return, including mag, ftype, Rrup, Vs30, lnY, sigma, specT, period, iflag, forearc, depth, Rhypo.
Details
Montalva, G. A., Bastias, N., and Rodriguez-Marek, A. (2017). Ground-Motion Prediction Equation for the Chilean Subduction Zone. Bulletin of the Seismological Society of America, 107(2), 901-911. doi:10.1785/0120160221
Examples
MBR17(6, 20, 0, 0, 760, 1, 10, 20)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.404956
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8384492
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $forearc
#> [1] 1
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
MBR17(7, 10, 0, 0, 760, 1, 10, 20)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.941077
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8384492
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $forearc
#> [1] 1
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rhypo
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>