Skip to contents

Mcverry2006Sub returns the ground-motion prediction with it sigma of Mcverry et al.(2006) Subduction GMPE.

Usage

Mcverry2006Sub(
  Mag,
  Rrup,
  Prd,
  ftype = 0,
  Ztor,
  Dip,
  rupwidth,
  depth,
  Sc = 0,
  Sd = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

fytpe=0 for interface, ftype=1 for intraslab.

Ztor

Depth to the top of the finite rupture model (km).

Dip

Dip angle of the fault plane.

rupwidth

Down-dip rupture width (km).

depth

hypocentral depth(km).

Sc

1 for site class C, 0 for others.

Sd

1 for site class D, 0 for others.

Value

A list will be return, including mag, Rrup, Rjb, ftype, specT, period, lnY, sigma, iflag, Vs30, Ztor, Z25, dip, depth, hwflag, Rx, rupwidth, regionflag, phi, tau.

Details

Mcverry, G. H., Zhao, J. X., Abrahamson, N. A., and Somerville, P. G. (2006). New Zealand acceleration response spectrum attenuation relations for crustal and subduction zone earthquakes, Bulletin of the New Zealand Society for Earthquake Engineering, 39(1), 1-58.

Examples

Mcverry2006Sub(6, 20, 0, 0, 0, 90, 10, 10, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.23603
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.5461007
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Sc
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Sd
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
Mcverry2006Sub(7, 20, 0, 0, 0, 90, 10, 10, 0, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.57134
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.4582092
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $rupwidth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Sc
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Sd
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>