Skip to contents

NCREE2011 returns the ground-motion prediction (rock site, Vs30>=360m/s) with it sigma of NCREE(2011) GMPE.

Usage

NCREE2011(Mag, Rrup, Prd)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

Value

A list will be return, including mag, Rrup, specT, period, lnY, sigma.

Details

National Center for Research on Earthquake Engineering (NCREE) (2011). Research on area source and attenuation law parameters and nuclear power plant site response measurement. Commissioned research report by the Atomic Energy Council, Institute of Nuclear Energy Research, Taiwan.

Examples

NCREE2011(6, 20, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.700805
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7477
#> attr(,"Csingle")
#> [1] TRUE
#> 
NCREE2011(7, 10, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 6.021311
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7477
#> attr(,"Csingle")
#> [1] TRUE
#>