Skip to contents

PhungCru17 returns the ground-motion prediction with it sigma of Phung et al.(2017) GMPE.

Usage

PhungCru17(
  Mag,
  Rrup,
  Prd,
  Vs30,
  Dip,
  Ztor,
  ftype = 0,
  Z1.0,
  Vs30_class = 1,
  msasflag = 0,
  regionflag = 1
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

Dip

Dip angle of the fault plane.

Ztor

Depth to the top of the finite rupture model (km).

ftype

style of faulting.

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

Vs30_class

1 measured, 0 estimated.

msasflag

Mainshock and Aftershocks flag, 0 = Mainshocks, 1 = Aftershocks.

regionflag

0 Global, 1 Taiwan

Value

A list will be return, including m, Rrup, specT, period2, lnY, sigma, iflag, vs, Delta, DTor, Ftype, depthvs10, vs30_class, regionflag, msasflag, phi, tau.

Details

Phung et al.(2017) Crustal GMPE

Examples

PhungCru17(6, 20, 0, 760, 90, 0, 0, 0.5, 1, 0,  1)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.308054
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6337379
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $msasflag
#> [1] 0
#> 
#> $phi
#> [1] 0.5239936
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3577662
#> attr(,"Csingle")
#> [1] TRUE
#> 
PhungCru17(7, 20, 0, 760, 90, 0, 0, 0.5, 1, 0,  1)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.018942
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.621331
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $msasflag
#> [1] 0
#> 
#> $phi
#> [1] 0.4989508
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3722963
#> attr(,"Csingle")
#> [1] TRUE
#>