Skip to contents

PhungCru18 returns the ground-motion prediction with it sigma of Phung et al.(2018) GMPE.

Usage

PhungCru18(
  Mag,
  Rrup,
  Rjb,
  Rx,
  Prd,
  Vs30,
  Dip,
  Ztor,
  ftype = 0,
  Z1.0,
  Vs30_class = 1,
  regionflag = 1,
  hwflag = 0
)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Rjb

Joyner and Boore distance(km), Numeric.

Rx

Horizontal distance(km) from top edge of rupture. Measured perpendicular to the fault strike.

Prd

Period of spectral acceleration.

Vs30

Vs30(m/s).

Dip

Dip angle of the fault plane.

Ztor

Depth to the top of the finite rupture model (km).

ftype

style of faulting.

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

Vs30_class

1 measured, 0 estimated.

regionflag

0 Global, 1 Taiwan

hwflag

hanging-wall flag, 1 for hanging-wall.

Value

A list will be return, including m, Rrup, Rjb, Rx, specT, period2, lnY, sigma, iflag, vs, Delta, DTor, Ftype, depthvs10, vs30_class, regionflag, phi, tau, HWflag, Rx.

Details

Phung et al.(2018) Crustal GMPE

Examples

PhungCru18(6, 20, 20, 20, 0, 760, 90, 0, 0, 0.5, 1, 1, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.271354
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6751122
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $phi
#> [1] 0.563111
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.3066667
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
PhungCru18(7, 20, 20, 20, 0, 760, 90, 0, 0, 0.5, 1, 1, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.944185
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6751122
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $dip
#> [1] 90
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $vs30_class
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $phi
#> [1] 0.563111
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.26
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $hwflag
#> [1] 0
#> 
#> $Rx
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>