Skip to contents

PhungSub18 returns the ground-motion prediction with it sigma of Phung et al.(2018) GMPE.

Usage

PhungSub18(Mag, Rrup, Prd, ftype = 0, Vs30, Z1.0, Ztor, regionflag = 1)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

fytpe=0 for interface, ftype=1 for intraslab.

Vs30

Vs30(m/s).

Z1.0

the depth to the shear-wave velocity horizon of 1.0(km/s).

Ztor

Depth to the top of the finite rupture model (km).

regionflag

0 Japan, 1 Taiwan

Value

A list will be return, including mag, ftype, Rrup, Vs30, lnY, sigma, specT, period, iflag, forearc, depth, Rhypo.

Details

Phung et al.(2018) Subduction GMPE

Examples

PhungSub18(6, 20, 0, 0, 760, 0.5, 0, 1)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 3.99133
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6376177
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
PhungSub18(7, 10, 0, 1, 760, 0.5, 0, 1)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Z1.0
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.771813
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.6376177
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
#> $regionflag
#> [1] 1
#> 
#> $ftype
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>