Skip to contents

Sub.Inter.Com.013 returns the ground-motion prediction with it sigma of Subduction interface Common form 013 GMPE.

Usage

Sub.Inter.Com.013(Mag, Rrup, Ztor, Prd)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Ztor

Depth to the top of the finite rupture model (km).

Prd

Period of spectral acceleration.

Value

A list will be return, including mag, Rrup, Ztor, pecT, lnY, sigma, iflag.

Details

Subduction interface common form 013

Examples

Sub.Inter.Com.013(6, 20, 5, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 5
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 3.957003
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.65
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
Sub.Inter.Com.013(7, 20, 2, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Ztor
#> [1] 2
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.861411
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.65
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#>