Skip to contents

Youngs97Rock returns the ground-motion prediction (rock site) with it sigma of Youngs et al.(1997) GMPE.

Usage

Youngs97Rock(Mag, Rrup, Prd, ftype = 0, depth)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Prd

Period of spectral acceleration.

ftype

fytpe=0 for interface, ftype=1 for intraslab

depth

hypocentral depth(km).

Value

A list will be return, including mag, Rrup, lnY, sigma, period, specT, ftype, depth, iflag.

Details

Youngs, R. R., S.-J. Chiou, W. J. Silva, and J. R. Humphrey (1997), Strong ground motion attenuation relationships for subduction zone earthquakes, Seismological Research Letters, 68(1), 58-73. doi:10.1785/gssrl.68.1.58

Examples

Youngs97Rock(6, 20, 0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 4.853267
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.85
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#> 
Youngs97Rock(7, 10, 0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.439364
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7500001
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 1
#>