Zh06Inter returns the ground-motion prediction with it sigma of Zhao et al.(2016) GMPE.
Value
A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.
Details
Zhao, J. et al. (2016),Ground-Motion Prediction Equations for Subduction Interface Earthquakes in Japan Using Site Class and Simple Geometric Attenuation Functions, Bulletin of the Seismological Society of America, 106(4), 1518-1534. doi:10.1785/0120150034
Examples
Zh16Inter(6, 20, 1.0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.265313
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8679689
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.553
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.669
#> attr(,"Csingle")
#> [1] TRUE
#>
Zh16Inter(7, 10, 1.0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.542356
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8679689
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.553
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.669
#> attr(,"Csingle")
#> [1] TRUE
#>