Skip to contents

Zh06Slab returns the ground-motion prediction with it sigma of Zhao et al.(2016) GMPE.

Usage

Zh16Slab(Mag, Rrup, sclass = 1, Prd = 0, depth = 10)

Arguments

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

sclass

site condition, 0 for Hard Rock, 1 for SC I, 2 for SC II, 3 for SC III, 4 for SC IV.

Prd

Period of spectral acceleration.

depth

focal depth(km).

Value

A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.

Details

Zhao, J. et al. (2016),Ground-Motion Prediction Equations for Subduction Slab Earthquakes in Japan Using Site Class and Simple Geometric Attenuation Functions, Bulletin of the Seismological Society of America, 106(4), 1535-1551. doi:10.1785/0120150056

Examples

Zh16Slab(6, 20, 1.0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 5.501801
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7439207
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.587
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.457
#> attr(,"Csingle")
#> [1] TRUE
#> 
Zh16Slab(7, 10, 1.0, 0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $lnY
#> [1] 7.011569
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sigma
#> [1] 0.7439207
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $iflag
#> [1] 0
#> 
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $phi
#> [1] 0.587
#> attr(,"Csingle")
#> [1] TRUE
#> 
#> $tau
#> [1] 0.457
#> attr(,"Csingle")
#> [1] TRUE
#>