Zh16Sub returns the ground-motion prediction with it sigma of Zhao et al.(2016) GMPE.
Arguments
- Mag
Earthquake momnet magnitude, Numeric.
- Rrup
Rupture distance(km), Numeric.
- sclass
site condition, 0 for Hard Rock, 1 for SC I, 2 for SC II, 3 for SC III, 4 for SC IV.
- Prd
Period of spectral acceleration.
- sourceclass
source type, 1 for Subduction - Interface, 2 for Subduction - Slab.
- depth
focal depth(km).
Value
A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.
Details
Zhao, J. et al. (2016),Ground-Motion Prediction Equations for Subduction Interface Earthquakes in Japan Using Site Class and Simple Geometric Attenuation Functions, Bulletin of the Seismological Society of America, 106(4), 1518-1534. doi:10.1785/0120150034 #'Zhao, J. et al. (2016),Ground-Motion Prediction Equations for Subduction Slab Earthquakes in Japan Using Site Class and Simple Geometric Attenuation Functions, Bulletin of the Seismological Society of America, 106(4), 1535-1551. doi:10.1785/0120150056
Examples
Zh16Sub(6, 20, 1.0, 0, 1.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.265313
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8679689
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.553
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.669
#> attr(,"Csingle")
#> [1] TRUE
#>
Zh16Sub(7, 10, 1.0, 0, 1.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.542356
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8679689
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.553
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.669
#> attr(,"Csingle")
#> [1] TRUE
#>