Skip to contents

atten2 returns the ground-motion prediction with it sigma of any GMPE.

Usage

atten2(
  GMPEname,
  Periods,
  Mag,
  Rrup,
  Ztor = 0,
  RV = 0,
  depth,
  ftype = 0,
  plot = FALSE
)

Arguments

GMPEname

Name of GMPE.

Periods

Periods of response spetra

Mag

Earthquake momnet magnitude, Numeric.

Rrup

Rupture distance(km), Numeric.

Ztor

Depth to the top of the finite rupture model (km).

RV

Indicator of reverse fault.

depth

Focal depth.

ftype

style of fault.

plot

flag for plot or not.

Value

A list will be return, including mag, Rjb, ftype, specT, period, lnY, sigma, iflag, Vs30, phi, tau.

Examples

atten2("LL08Rock", 0, Mag=c(6,7,8), 20, 0, 0, 10, 0, FALSE)
#>   mag Rrup specT period        lnY  sigma iflag depth ftype
#> 1   6   20     0      0 0.09467916 0.5268     1    10     0
#> 2   7   20     0      0 0.15137929 0.5268     1    10     0
#> 3   8   20     0      0 0.20557250 0.5268     1    10     0
atten2("LL08Rock", Periods=c(0.01, 0.1, 0.2, 0.5, 1, 2, 5), 6, 10, 0, 0, 10, 0, FALSE)
#>   mag Rrup      specT     period        lnY  sigma iflag depth ftype
#> 1   6   10 0.01000000 0.01000000 0.16247691 0.5218     0    10     0
#> 2   6   10 0.09999999 0.09999999 0.24225548 0.5806     0    10     0
#> 3   6   10 0.19999999 0.19999999 0.23730400 0.6059     0    10     0
#> 4   6   10 0.50000000 0.50000000 0.09782724 0.7145     0    10     0
#> 5   6   10 1.00000000 1.00000000 0.03792540 0.7983     0    10     0
#> 6   6   10 2.00000000 2.00000000 0.01108411 0.8766     0    10     0
#> 7   6   10 5.00000000 5.00000000 0.00157840 0.7654     0    10     0