AB03 returns the ground-motion prediction with it sigma of Atkinson and Boore(2003) GMPE.
Arguments
- Mag
Earthquake momnet magnitude, Numeric.
- Rrup
Rupture distance(km), Numeric.
- Prd
Period of spectral acceleration.
- ftype
style of faulting.
- depth
hypocentral depth(km).
- Sc
NEHRP B Sc=0, Sd=0, Se=0, Vs>760m/s, NEHRP C Sc=1, Sd=0, Se=0, 360<Vs<760
- Sd
NEHRP D Sc=0, Sd=1, Se=0, 180<Vs<360
- Se
NEHRP E Sc=0, Sd=0, Se=1, Vs<180
Value
A list will be return, including mag, Rrup, lnY, sigma, specT, period, iflag, ftype, depth, Sc, Sd, Se.
Details
Atkinson, G., and D. Boore (2003), Empirical ground-motion relations for subduction-zone earthquakes and their application to cascadia and other regions, Bulletin of the Seismological Society of America, 93(4), 1703-1729. doi:10.1785/0120020156
Examples
AB03(6, 20, 0, 0, 10, 0, 0, 0)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 3.400256
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5295946
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sc
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sd
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Se
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
AB03(7, 10, 0, 0, 10, 0, 0, 0)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.612576
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5295946
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sc
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sd
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Se
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>