AC10 returns the ground-motion prediction with it sigma of Akkar and Cagnan(2010) GMPE.
Value
A list will be return, including mag, Rjb, specT, period, lnY, sigma, iflag, Vs30, ftype, pga4nl.
Details
Akkar, S., and Z. Cagnan (2010), A local ground-motion predictive model for turkey, and its comparison with other regional and global ground-motion models, Bulletin of the Seismological Society of America, 100(6), 2978-2995. doi:10.1785/0120090367
Examples
AC10(6, 20, 0, 0, 760)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 3.902359
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8322
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $pga4nl
#> [1] 49.5191
#> attr(,"Csingle")
#> [1] TRUE
#>
AC10(7, 10, 0, 0, 760)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.224807
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.8322
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $pga4nl
#> [1] 185.8253
#> attr(,"Csingle")
#> [1] TRUE
#>