AM09 returns the ground-motion prediction with it sigma of Atkinson and Macias (2009) GMPE.
(Cascadia Subduction interface, Horizontal NEHRP B/C)
Details
Atkinson, G. M., and Macias, M. (2009). Predicted Ground Motions for Great Interface Earthquakes in the Cascadia Subduction Zone. Bulletin of the Seismological Society of America, 99(3), 1552-1578. doi:10.1785/0120080147
Examples
AM09(6, 20, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.774757
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5526
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
AM09(7, 10, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.958539
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5526
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>