BI14.tw.B01 returns the ground-motion prediction with it sigma of Bindi et al.(2014) GMPE
adjusted to Taiwan.
Value
A list will be return, including mag, Rjb, ftype, specT, period, lnY, sigma, iflag, Vs30, phi, tau.
Details
Bindi, D., M. Massa, L. Luzi, G. Ameri, F. Pacor, R. Puglia, and P. Augliera (2014), Pan-european ground-motion prediction equations for the average horizontal component of pGA, pGV, and 5 dataset, Bulletin of Earthquake Engineering, 12(1), 391-430. doi:10.1007/s10518-013-9525-5
Examples
BI14.tw.B01(6, 20, 0, 0, 760)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.045848
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.6501487
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.3153394
#> attr(,"Csingle")
#> [1] TRUE
#>
BI14.tw.B01(7, 10, 0, 0, 760)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.167866
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.6501487
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.3153394
#> attr(,"Csingle")
#> [1] TRUE
#>