Camp03H returns the ground-motion prediction with it sigma of Campbell and Bozorgnia(2003) GMPE.
Value
A list will be return, including mag, Rseis, Rjb, lnY, sigma, specT, period, Svfs, Ssr, Sfr, Frv, Fth, hwflag, iflag.
Details
Campbell, Kenneth W. and Bozorgnia, Yousef (2003), Updated Near-Source Ground-Motion (Attenuation) Relations for the Horizontal and Vertical Components of Peak Ground Acceleration and Acceleration Response Spectra, Bulletin of the Seismological Society of America, 93(1), 314-331. doi:10.1785/0120020029
Examples
Camp03H(6, 20, 20, 0, 0, 0, 0, 0, 0)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rseis
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.74306
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Svfs
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Ssr
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sfr
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Frv
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Fth
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $hwflag
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
Camp03H(7, 10, 20, 0, 0, 0, 0, 0, 0)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rseis
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rjb
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.336952
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.43
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Svfs
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Ssr
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Sfr
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Frv
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Fth
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $hwflag
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>