GK16 returns the ground-motion prediction with it sigma of Graizer and Kalkan(2016) GMPE.
Value
A list will be return, including mag, Rrup, specT, ftype, period, lnY, sigma, iflag, Vs30, q0, Z15.
Details
Graizer and E. Kalkan.(2016) Summary of the GK15 ground-motion prediction equation for horizontal PGA and 5 Bulletin of the Seismological Society of America, 106(2), 687-707. doi:10.1785/0120150194
Examples
GK16(6, 20, 0, 0, 760, 150, 1)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.559353
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5305557
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $q0
#> [1] 150
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Z1.5
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
GK16(7, 10, 0, 0, 760, 150, 1)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.713228
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.5305557
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $q0
#> [1] 150
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Z1.5
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>