LL08.C02 returns the ground-motion prediction with it sigma of adjusted Lin and Lee(2008) GMPE.
Value
A list will be return, including mag, Rrup, specT, period, lnY, sigma, iflag, Ztor, ftype, Vs30.
Details
Lin, P., and C. Lee (2008), Ground-motion attenuation relationships for subduction-zone earthquakes in northeastern taiwan, Bulletin of the Seismological Society of America, 98(1), 220-240. doi:10.1785/0120060002
Examples
LL08.C02(6, 20, 10, 0, 0, 760)
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 3.955745
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.4889251
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $Ztor
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>
LL08.C02(7, 10, 10, 0, 0, 760)
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.80583
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.4889251
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 1
#>
#> $Ztor
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Vs30
#> [1] 760
#> attr(,"Csingle")
#> [1] TRUE
#>