Zh06 returns the ground-motion prediction with it sigma of Zhao et al.(2006) GMPE.
Value
A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.
Details
Zhao, J. et al. (2006), Attenuation relations of strong ground motion in japan using site classification based on predominant period, Bulletin of the Seismological Society of America, 96(3), 898-913. doi:10.1785/0120050122
Examples
Zh06(6, 20, 0, 1.0, 0, 0.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.443553
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.6757403
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.604
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.303
#> attr(,"Csingle")
#> [1] TRUE
#>
Zh06(7, 10, 0, 1.0, 0, 0.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 5.738294
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.6757403
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.604
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.303
#> attr(,"Csingle")
#> [1] TRUE
#>