Zh16Cru returns the ground-motion prediction with it sigma of Zhao et al.(2016) GMPE.
Arguments
- Mag
Earthquake momnet magnitude, Numeric.
- Rrup
Rupture distance(km), Numeric.
- ftype
style of faulting, -1 for Normal, -0.5 for Normal-Oblique, 0 for Strike-Slip, 0.5 for Reverse-Oblique and 1 for Reverse.
- sclass
site condition, 0 for Hard Rock, 1 for SC I, 2 for SC II, 3 for SC III, 4 for SC IV.
- Prd
Period of spectral acceleration.
- sourceclass
source type, 0 for crustal, 3 for Upper mantle.
- depth
focal depth(km).
Value
A list will be return, including mag, Rrup, ftype, lnY, sigma, sclass, specT, attenName, period, iflag, sourcetype, depth, phi, tau.
Details
Zhao, J. et al. (2016), Ground-Motion Prediction Equations for Shallow Crustal and Upper-Mantle Earthquakes in Japan Using Site Class and Simple Geometric Attenuation Functions, Bulletin of the Seismological Society of America, 106(4), 1552-1569. doi:10.1785/0120150063
Examples
Zh16Cru(6, 20, 0, 1.0, 0, 0.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 6
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 20
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 4.892986
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.6797183
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.556
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.391
#> attr(,"Csingle")
#> [1] TRUE
#>
Zh16Cru(7, 10, 0, 1.0, 0, 0.0, 10)
#> Warning: passing a char vector to .Fortran is not portable
#> $mag
#> [1] 7
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $Rrup
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $ftype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $lnY
#> [1] 6.036662
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sigma
#> [1] 0.6797183
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $sclass
#> [1] 1
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $specT
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $period
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $iflag
#> [1] 0
#>
#> $sourcetype
#> [1] 0
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $depth
#> [1] 10
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $phi
#> [1] 0.556
#> attr(,"Csingle")
#> [1] TRUE
#>
#> $tau
#> [1] 0.391
#> attr(,"Csingle")
#> [1] TRUE
#>